==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ExportRecurrencePeriodArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The start and end date for recurrence schedule.
 * @property from The start date of recurrence.
 * @property to The end date of recurrence.
 */
public data class ExportRecurrencePeriodArgs(
    public val from: Output<String>,
    public val to: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs =
        com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs.builder()
            .from(from.applyValue({ args0 -> args0 }))
            .to(to?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExportRecurrencePeriodArgs].
 */
@PulumiTagMarker
public class ExportRecurrencePeriodArgsBuilder internal constructor() {
    private var from: Output<String>? = null

    private var to: Output<String>? = null

    /**
     * @param value The start date of recurrence.
     */
    @JvmName("slpaqghywxfqbqyp")
    public suspend fun from(`value`: Output<String>) {
        this.from = value
    }

    /**
     * @param value The end date of recurrence.
     */
    @JvmName("mpuccsvhundrbmai")
    public suspend fun to(`value`: Output<String>) {
        this.to = value
    }

    /**
     * @param value The start date of recurrence.
     */
    @JvmName("tggniglpnxrycmds")
    public suspend fun from(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.from = mapped
    }

    /**
     * @param value The end date of recurrence.
     */
    @JvmName("rtaalpkkrrcfqdaf")
    public suspend fun to(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.to = mapped
    }

    internal fun build(): ExportRecurrencePeriodArgs = ExportRecurrencePeriodArgs(
        from = from ?: throw PulumiNullFieldException("from"),
        to = to,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ExportRecurrencePeriodArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The start and end date for recurrence schedule.
 * @property from The start date of recurrence.
 * @property to The end date of recurrence.
 */
public data class ExportRecurrencePeriodArgs(
    public val from: Output<String>,
    public val to: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs =
        com.pulumi.azurenative.costmanagement.inputs.ExportRecurrencePeriodArgs.builder()
            .from(from.applyValue({ args0 -> args0 }))
            .to(to?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExportRecurrencePeriodArgs].
 */
@PulumiTagMarker
public class ExportRecurrencePeriodArgsBuilder internal constructor() {
    private var from: Output<String>? = null

    private var to: Output<String>? = null

    /**
     * @param value The start date of recurrence.
     */
    @JvmName("aoluioympledpohg")
    public suspend fun from(`value`: Output<String>) {
        this.from = value
    }

    /**
     * @param value The end date of recurrence.
     */
    @JvmName("swngyrsalmovvwla")
    public suspend fun to(`value`: Output<String>) {
        this.to = value
    }

    /**
     * @param value The start date of recurrence.
     */
    @JvmName("scdlhnwayjytjfqg")
    public suspend fun from(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.from = mapped
    }

    /**
     * @param value The end date of recurrence.
     */
    @JvmName("pevpxgrtytgbpuqx")
    public suspend fun to(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.to = mapped
    }

    internal fun build(): ExportRecurrencePeriodArgs = ExportRecurrencePeriodArgs(
        from = from ?: throw PulumiNullFieldException("from"),
        to = to,
    )
}
